@@ -15,7 +15,7 @@ use overload
 use Validation::Class::Simple;
 use Validation::Class::Util;
 
-our $VERSION = '7.900009'; # VERSION
+our $VERSION = '7.900010'; # VERSION
 
 
 sub new {
@@ -179,13 +179,13 @@ sub AUTOLOAD {
 
     }
 
-    exit carp sprintf q(Can't locate object method "%s" via package "%s"),
+    croak sprintf q(Can't locate object method "%s" via package "%s"),
         $routine, ((ref $_[0] || $_[0]) || 'main')
     ;
 
 }
 
-sub DESTROY;
+sub DESTROY {}
 
 1;
 
@@ -198,7 +198,7 @@ Validation::Class::Simple::Streamer - Simple Streaming Data Validation
 
 =head1 VERSION
 
-version 7.900009
+version 7.900010
 
 =head1 SYNOPSIS
 
